@@ -1,11 +1,11 @@
 """Build a book with Jupyter Notebooks and Sphinx."""
 from pathlib import Path
 
-from .toc import add_toc_to_sphinx, add_toctree
-from .directive.toc import TableofContents, SwapTableOfContents
+from sphinx.util import logging
 
+__version__ = "0.11.1"
 
-__version__ = "0.10.1"
+logger = logging.getLogger(__name__)
 
 
 def add_static_files(app, config):
@@ -22,24 +22,11 @@ def add_static_files(app, config):
 # We connect this function to the step after the builder is initialized
 def setup(app):
 
-    # Updates `master_doc` using the first item of `_toc.yml`
-    app.connect("config-inited", add_toc_to_sphinx)
-
-    # Add toctrees to each content page using `_toc.yml`
-    app.connect("source-read", add_toctree)
-
-    # Path for `_toc.yml`
-    app.add_config_value("globaltoc_path", "toc.yml", "env")
-
+    app.add_config_value("use_jupyterbook_latex", True, "env")
     # Add custom static files to the sphinx build
     app.connect("config-inited", add_static_files)
 
-    # Directives
-    app.add_directive("tableofcontents", TableofContents)
-
-    # Transforms
-    app.add_post_transform(SwapTableOfContents)
-
+    # Extensions
     return {
         "version": __version__,
         "parallel_read_safe": True,
